@@ -2,14 +2,12 @@ from thonny import THONNY_USER_DIR, get_workbench
 
 #Default config
 DEFAULT_PATH = THONNY_USER_DIR+"/LoggingPlugin/"
-DEFAULT_SERVER = 'http://127.0.0.1:8000'
+DEFAULT_SERVER = 'http://127.0.0.1:8000' #'http://localhost:8081' 
 DEFAULT_STORE = True
 DEFAULT_SEND = False
 DEFAULT_LOG_IN_CONSOLE = False
-#VERSION = "0.1.6"
 
-TERMS_OF_USE = "Acceptez vous que les données utilisateur issues de thonny soient collectées à des fins de recherche ? \nSi oui : attention de ne pas faire figurer de données personnelles en dehors du commentaire en tête de fichier et du nom du fichier (qui ne sont pas collectés).\nPlus d'informations dans le menu tools --> LoggingPlugin."
-URL_TERMS_OF_USE = "https://www.cristal.univ-lille.fr"
+URL_TERMS_OF_USE = "https://www.fil.univ-lille.fr/~L1S1Info/last/collecte_donnees_thonny.pdf"
 
 #Dict of options name and default value
 OPTIONS = {
